@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : Catalogue
-Version : 1.0.5
+Version : 1.2.0
 Author  : Stefano Covino
-Date    : 15/04/2013
+Date    : 26/07/2013
 E-mail  : stefano.covino@brera.inaf.it
 URL     : http://www.me.oa-brera.inaf.it/utenti/covino
 
@@ -19,11 +19,13 @@ History : (29/09/2010) First named version.
         : (28/03/2011) AGN optical standard stars.
         : (11/06/2011) USNOB1 class.
         : (15/04/2013) SDSS query script.
+        : (06/05/2013) SDSS class.
+        : (26/07/2013) APASS class
 """
 
 
 
-__all__ = ['AGNOptRefStarsClass', 'AstroWiseStandardStarsClass', 'BrightStarClass', 'CatalogueConstants',
-           'GetVizierCat', 'NIRStandardStarsClass','ParseVisierCat', 'StetsonJohnsonStandardStarsClass',
-           'TWOMASSClass', 'USNOB1Class', 'USNOClass']
+__all__ = ['AGNOptRefStarsClass', 'APASSClass', 'AstroWiseStandardStarsClass', 'BrightStarClass',
+           'CatalogueConstants', 'GetVizierCat', 'NIRStandardStarsClass','ParseVisierCat',
+           'SDSSClass', 'StetsonJohnsonStandardStarsClass', 'TWOMASSClass', 'USNOB1Class', 'USNOClass']
 
