@@ -2,10 +2,10 @@
 
 Context : SRP
 Module  : SRPConstants.py
-Version : 1.14.1
+Version : 1.14.2
 Status  : approved
 Author  : Stefano Covino, Daniele Malesani
-Date    : 27/08/2012
+Date    : 13/12/2012
 E-mail  : stefano.covino@brera.inaf.it
 URL     : http://www.merate.mi.astro.it/~covino
 Purpose : Collection of constants, functions and classes for SRP.
@@ -85,6 +85,7 @@ History : (20/05/2003) First version.
         : (28/02/2012) TNG Dolores spec and pol entries.
         : (31/07/2012) Updated TNG pol entries.
         : (27/08/2012) Updated constants for average sigma-clipping.
+        : (13/12/2012) Imporvements to FORS imaging polarimetry keywords.
 """
 
 import os
@@ -203,6 +204,7 @@ HIERARCH ESO DET READ CLOCK
 HIERARCH ESO TEL AIRM START
 HIERARCH ESO TEL AIRM END
 HIERARCH ESO INS PIXSCALE
+EXTNAME
 """
 SRPLASCIMA  = "SRPLASCIMA"
 LASCIMA	  = """NAXIS1
@@ -467,24 +469,25 @@ HIERARCH ESO INS PIXSCALE
 """
 SRPVLTFORSIPOL = "VLTFORSIPOL"
 VLTFORSIPOL = """
-NAXIS   
-NAXIS1  
-NAXIS2  
+NAXIS
+NAXIS1
+NAXIS2
 DATE-OBS
-EXPTIME 
-RA      
-DEC     
-OBJECT  
+EXPTIME
+RA
+DEC
+OBJECT
 INSTRUME
-AIRMASS 
+AIRMASS
 IMAGETYP
-FILTER1 
-HIERARCH ESO DPR CATG        
-HIERARCH ESO DPR TECH        
-HIERARCH ESO TEL PARANG START
-HIERARCH ESO INS PIXSCALE    
-HIERARCH ESO INS MODE        
-HIERARCH ESO INS COLL NAME   
+FILTER1
+PARANGST
+RETANG
+HIERARCH ESO DPR CATG
+HIERARCH ESO DPR TECH
+HIERARCH ESO INS PIXSCALE
+HIERARCH ESO INS MODE
+HIERARCH ESO INS COLL NAME
 HIERARCH ESO INS RETA2 POSANG
 HIERARCH ESO OBS TARG NAME
 EXTNAME
