@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : Fits.py
-Version : 1.6.1
+Version : 1.7.0
 Author  : Stefano Covino
-Date    : 19/08/2013
+Date    : 16/10/2013
 E-mail  : stefano.covino@brera.inaf.it
 URL:    : http://www.merate.mi.astro.it/utenti/covino
 
@@ -24,6 +24,7 @@ History : (23/05/2010) First version.
         : (04/10/2010) Possibility to remove stars close to frame border.
         : (25/10/2010) Basic statistics for frames.
         : (19/08/2013) Possiblity to read different extensions and original BITPIX saved.
+        : (16/10/2013) Frame center in pixel.
 """
 
 import os
@@ -168,4 +169,11 @@ class FitsImage:
         std = numpy.std(self.Data)
         median = numpy.median(self.Data)
         max = numpy.max(self.Data)
-        return mean,std,median,max
\ No newline at end of file
+        return mean,std,median,max
+
+
+
+    def GetFrameCenterPix (self):
+        fs = self.GetFrameSizePix()
+        return int(fs[0]/2.), int(fs[1]/2.)
+
