@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : Stats.py
-Version : 1.0.0
+Version : 1.1.0
 Author  : Stefano Covino
-Date    : 21/05/2010
+Date    : 20/04/2012
 E-mail  : stefano.covino@brera.inaf.it
 URL:    : http://www.merate.mi.astro.it/utenti/covino
 
@@ -13,6 +13,7 @@ Usage   : to be imported
 Remarks : input is a list of (x,sigmax)
 
 History : (21/05/2010) First version.
+        : (20/4/2012) Case with no data considered.
 
 """
 
@@ -21,6 +22,11 @@ import math
 
 
 def WeightedMean(lst):
+    if len(lst) < 1:
+        return 0,0,0,0
+    elif len(lst) == 1:
+        return lst[0][0], lst[0][1], lst[0][1], 1.
+    #
     num = 0.0
     den = 0.0
     for i in lst:
