@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : SRP
-Version : 1.1.23
+Version : 1.1.30
 Author  : Stefano Covino
-Date    : 24/08/2013
+Date    : 16/10/2013
 E-mail  : stefano.covino@brera.inaf.it
 URL     : http://www.me.oa-brera.inaf.it/utenti/covino
 
@@ -101,6 +101,12 @@ History : (28/09/2010) First named version.
         : (18/08/2013) V. 3.10.11b2.
         : (19/08/2013) V. 3.10.11b3 and b4.
         : (24/08/2013) V. 3.10.11.
+        : (26/08/2013) V. 3.10.12b1.
+        : (29/08/2013) V. 3.10.12b2 and b3.
+        : (30/08/2013) V. 3.10.12b4.
+        : (02/09/2013) V. 3.10.12b5.
+        : (03/09/2013) V. 3.10.12b6.
+        : (16/10/2013) V. 3.10.12b7 and 3.10.12
 """
 
 
@@ -115,5 +121,5 @@ __all__ = ['SRPCatalogue', 'SRPFits', 'SRPFrames', 'SRPMath', 'SRPNet', 'SRPPhot
 
 
 # Version
-__version__ = '3.10.11'
+__version__ = '3.10.12'
 
